@@ -42,6 +42,7 @@
 #include "gs-prefs.h"
 #include "gs-window.h"
 #include "subprocs.h"
+#include "xfce-desktop-utils.h"
 
 static void     gs_window_finalize       (GObject       *object);
 
@@ -361,141 +362,6 @@ gs_window_real_unrealize (GtkWidget *widget) {
     }
 }
 
-/* copied from gdk */
-extern char **environ;
-
-static gchar **
-spawn_make_environment_for_display (GdkDisplay  *display,
-                                    gchar      **envp) {
-    gchar       **retval = NULL;
-    const gchar  *display_name;
-    gint          display_index = -1;
-    gint          i, env_len;
-
-    g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
-
-    if (envp == NULL)
-        envp = environ;
-
-    for (env_len = 0; envp[env_len]; env_len++)
-        if (strncmp (envp[env_len], "DISPLAY", strlen ("DISPLAY")) == 0)
-            display_index = env_len;
-
-    retval = g_new (char *, env_len + 1);
-    retval[env_len] = NULL;
-
-    display_name = gdk_display_get_name (display);
-
-    for (i = 0; i < env_len; i++)
-        if (i == display_index)
-            retval[i] = g_strconcat ("DISPLAY=", display_name, NULL);
-        else
-            retval[i] = g_strdup (envp[i]);
-
-    g_assert (i == env_len);
-
-    return retval;
-}
-
-static gboolean
-spawn_command_line_on_display_sync (GdkDisplay  *display,
-                                    const gchar  *command_line,
-                                    char        **standard_output,
-                                    char        **standard_error,
-                                    int          *exit_status,
-                                    GError      **error) {
-    char     **argv = NULL;
-    char     **envp = NULL;
-    gboolean   retval;
-
-    g_return_val_if_fail (command_line != NULL, FALSE);
-
-    if (!g_shell_parse_argv (command_line, NULL, &argv, error)) {
-        return FALSE;
-    }
-
-    envp = spawn_make_environment_for_display (display, NULL);
-
-    retval = g_spawn_sync (NULL,
-                           argv,
-                           envp,
-                           G_SPAWN_SEARCH_PATH,
-                           NULL,
-                           NULL,
-                           standard_output,
-                           standard_error,
-                           exit_status,
-                           error);
-
-    g_strfreev (argv);
-    g_strfreev (envp);
-
-    return retval;
-}
-
-static GdkVisual *
-get_best_visual_for_display (GdkDisplay *display) {
-    GdkScreen     *screen;
-    char          *command;
-    char          *std_output;
-    int            exit_status;
-    GError        *error;
-    unsigned long  v;
-    char           c;
-    GdkVisual     *visual;
-    gboolean       res;
-
-    visual = NULL;
-    screen = gdk_display_get_default_screen (display);
-
-    command = g_build_filename (LIBEXECDIR, "xfce4-screensaver-gl-helper", NULL);
-
-    error = NULL;
-    std_output = NULL;
-    res = spawn_command_line_on_display_sync (display,
-                                              command,
-                                              &std_output,
-                                              NULL,
-                                              &exit_status,
-                                              &error);
-    if (!res) {
-        gs_debug ("Could not run command '%s': %s", command, error->message);
-        g_error_free (error);
-        goto out;
-    }
-
-    if (1 == sscanf (std_output, "0x%lx %c", &v, &c)) {
-        if (v != 0) {
-            VisualID      visual_id;
-
-            visual_id = (VisualID) v;
-            visual = gdk_x11_screen_lookup_visual (screen, visual_id);
-
-            gs_debug ("Found best GL visual for display %s: 0x%x",
-                      gdk_display_get_name (display),
-                      (unsigned int) visual_id);
-        }
-    }
-out:
-    g_free (std_output);
-    g_free (command);
-
-    return g_object_ref (visual);
-}
-
-static void
-widget_set_best_visual (GtkWidget *widget) {
-    GdkVisual *visual;
-
-    g_return_if_fail (widget != NULL);
-
-    visual = get_best_visual_for_display (gtk_widget_get_display (widget));
-    if (visual != NULL) {
-        gtk_widget_set_visual (widget, visual);
-        g_object_unref (visual);
-    }
-}
-
 static void
 gs_window_real_realize (GtkWidget *widget) {
     GdkMonitor *monitor = GS_WINDOW (widget)->priv->monitor;
@@ -894,7 +760,6 @@ error_watch (GIOChannel   *source,
                 finished = TRUE;
                 break;
             case G_IO_STATUS_ERROR:
-                finished = TRUE;
                 gs_debug ("Error reading from child: %s\n", error->message);
                 g_error_free (error);
                 return FALSE;
@@ -1237,7 +1102,6 @@ keyboard_process_watch (GIOChannel   *source,
                 finished = TRUE;
                 break;
             case G_IO_STATUS_ERROR:
-                finished = TRUE;
                 gs_debug ("Error reading from child: %s\n", error->message);
                 g_error_free (error);
                 return FALSE;
@@ -1434,7 +1298,6 @@ dialog_process_watch (GIOChannel   *source,
                 finished = TRUE;
                 break;
             case G_IO_STATUS_ERROR:
-                finished = TRUE;
                 gs_debug ("Error reading from child: %s\n", error->message);
                 g_error_free (error);
                 return FALSE;
@@ -1890,7 +1753,7 @@ static void
 gs_window_real_get_preferred_width (GtkWidget *widget,
                                     gint      *minimal_width,
                                     gint      *natural_width) {
-    GtkRequisition requisition;
+    GtkRequisition requisition = { 0 };
     gs_window_real_size_request (widget, &requisition);
     *minimal_width = *natural_width = requisition.width;
 }
@@ -1899,7 +1762,7 @@ static void
 gs_window_real_get_preferred_height (GtkWidget *widget,
                                      gint      *minimal_height,
                                      gint      *natural_height) {
-    GtkRequisition requisition;
+    GtkRequisition requisition = { 0 };
     gs_window_real_size_request (widget, &requisition);
     *minimal_height = *natural_height = requisition.height;
 }
