@@ -65,7 +65,7 @@ static GtkBuilder     *builder = NULL;
 static GSThemeManager *theme_manager = NULL;
 static GSJob          *job = NULL;
 static XfconfChannel  *screensaver_channel = NULL;
-static XfconfChannel  *xfpm_channel = NULL;
+static XfceScreensaver *xfce_screensaver = NULL;
 
 static gboolean        idle_delay_writable;
 static gboolean        lock_delay_writable;
@@ -347,11 +347,11 @@ config_get_lock_on_suspend_hibernate_enabled (gboolean *is_writable) {
     gboolean lock;
 
     if (is_writable) {
-        *is_writable = !xfconf_channel_is_property_locked (xfpm_channel,
+        *is_writable = !xfconf_channel_is_property_locked (screensaver_channel,
                                                            KEY_LOCK_ON_SLEEP);
     }
 
-    lock = xfconf_channel_get_bool (xfpm_channel,
+    lock = xfconf_channel_get_bool (screensaver_channel,
                                     KEY_LOCK_ON_SLEEP,
                                     DEFAULT_KEY_LOCK_ON_SLEEP);
 
@@ -360,7 +360,7 @@ config_get_lock_on_suspend_hibernate_enabled (gboolean *is_writable) {
 
 static void
 config_set_lock_on_suspend_hibernate_enabled (gboolean lock) {
-    xfconf_channel_set_bool (xfpm_channel, KEY_LOCK_ON_SLEEP, lock);
+    xfconf_channel_set_bool (screensaver_channel, KEY_LOCK_ON_SLEEP, lock);
 }
 
 static gboolean
@@ -1700,141 +1700,6 @@ setup_for_lid_switch (void) {
     }
 }
 
-static gchar **
-spawn_make_environment_for_display (GdkDisplay  *display,
-                                    gchar      **envp) {
-    gchar        **retval = NULL;
-    const gchar  *display_name;
-    gint          display_index = -1;
-    gint          i, env_len;
-
-    g_return_val_if_fail (GDK_IS_DISPLAY (display), NULL);
-
-    /* environ is declared in gs-window-x11.c */
-    if (envp == NULL)
-        envp = environ;
-
-    for (env_len = 0; envp[env_len]; env_len++)
-        if (strncmp (envp[env_len], "DISPLAY", strlen ("DISPLAY")) == 0)
-            display_index = env_len;
-
-    retval = g_new (char *, env_len + 1);
-    retval[env_len] = NULL;
-
-    display_name = gdk_display_get_name (display);
-
-    for (i = 0; i < env_len; i++)
-        if (i == display_index)
-            retval[i] = g_strconcat ("DISPLAY=", display_name, NULL);
-        else
-            retval[i] = g_strdup (envp[i]);
-
-    g_assert (i == env_len);
-
-    return retval;
-}
-
-static gboolean
-spawn_command_line_on_display_sync (GdkDisplay  *display,
-                                    const gchar  *command_line,
-                                    char        **standard_output,
-                                    char        **standard_error,
-                                    int          *exit_status,
-                                    GError      **error) {
-    char     **argv = NULL;
-    char     **envp = NULL;
-    gboolean   retval;
-
-    g_return_val_if_fail (command_line != NULL, FALSE);
-
-    if (!g_shell_parse_argv (command_line, NULL, &argv, error)) {
-        return FALSE;
-    }
-
-    envp = spawn_make_environment_for_display (display, NULL);
-
-    retval = g_spawn_sync (NULL,
-                           argv,
-                           envp,
-                           G_SPAWN_SEARCH_PATH,
-                           NULL,
-                           NULL,
-                           standard_output,
-                           standard_error,
-                           exit_status,
-                           error);
-
-    g_strfreev (argv);
-    g_strfreev (envp);
-
-    return retval;
-}
-
-
-static GdkVisual *
-get_best_visual_for_display (GdkDisplay *display) {
-    GdkScreen     *screen;
-    char          *command;
-    char          *std_output;
-    int            exit_status;
-    GError        *error;
-    unsigned long  v;
-    char           c;
-    GdkVisual     *visual;
-    gboolean       res;
-
-    visual = NULL;
-    screen = gdk_display_get_default_screen (display);
-
-    command = g_build_filename (LIBEXECDIR, "xfce4-screensaver-gl-helper", NULL);
-
-    error = NULL;
-    std_output = NULL;
-    res = spawn_command_line_on_display_sync (display,
-                                              command,
-                                              &std_output,
-                                              NULL,
-                                              &exit_status,
-                                              &error);
-    if (!res) {
-        gs_debug ("Could not run command '%s': %s", command, error->message);
-        g_error_free (error);
-        goto out;
-    }
-
-    if (1 == sscanf (std_output, "0x%lx %c", &v, &c)) {
-        if (v != 0) {
-            VisualID visual_id;
-
-            visual_id = (VisualID) v;
-            visual = gdk_x11_screen_lookup_visual (screen, visual_id);
-
-            gs_debug ("Found best GL visual for display %s: 0x%x",
-                      gdk_display_get_name (display),
-                      (unsigned int) visual_id);
-        }
-    }
-out:
-    g_free (std_output);
-    g_free (command);
-
-    return visual;
-}
-
-
-static void
-widget_set_best_visual (GtkWidget *widget) {
-    GdkVisual *visual;
-
-    g_return_if_fail (widget != NULL);
-
-    visual = get_best_visual_for_display (gtk_widget_get_display (widget));
-    if (visual != NULL) {
-        gtk_widget_set_visual (widget, visual);
-        g_object_unref (visual);
-    }
-}
-
 static gboolean
 setup_treeview_idle (gpointer user_data) {
     GtkWidget *preview;
@@ -1947,12 +1812,6 @@ configure_capplet (void) {
                       G_CALLBACK (key_changed_cb),
                       NULL);
 
-    xfpm_channel = xfconf_channel_get(XFPM_XFCONF_CHANNEL);
-    g_signal_connect (xfpm_channel,
-                      "property-changed",
-                      G_CALLBACK (key_changed_cb),
-                      NULL);
-
     if (!is_program_in_path (CONFIGURE_COMMAND)) {
         gtk_widget_set_no_show_all (configure_toolbar, TRUE);
         gtk_widget_hide (configure_toolbar);
@@ -2139,9 +1998,6 @@ finalize_capplet (void) {
     if (screensaver_channel)
       g_signal_handlers_disconnect_by_func (screensaver_channel, key_changed_cb, NULL);
 
-    if (xfpm_channel)
-      g_signal_handlers_disconnect_by_func (xfpm_channel, key_changed_cb, NULL);
-
     if (active_theme)
         g_free (active_theme);
 }
@@ -2176,6 +2032,9 @@ main (int    argc,
         return EXIT_FAILURE;
     }
 
+    /* keep "/lock/sleep-activation" in sync with other components */
+    xfce_screensaver = xfce_screensaver_new ();
+
     job = gs_job_new ();
     theme_manager = gs_theme_manager_new ();
 
@@ -2208,13 +2067,7 @@ main (int    argc,
         /* Get plug child widget */
         plug_child = gtk_builder_get_object (builder, "plug-child");
 
-#if LIBXFCE4UI_CHECK_VERSION (4, 13, 2)
         xfce_widget_reparent (GTK_WIDGET(plug_child), plug);
-#else
-        G_GNUC_BEGIN_IGNORE_DEPRECATIONS /* GTK 3.14 */
-        gtk_widget_reparent (GTK_WIDGET(plug_child), plug);
-        G_GNUC_END_IGNORE_DEPRECATIONS
-#endif
 
         gtk_widget_show_all (GTK_WIDGET(plug_child));
 
@@ -2233,6 +2086,9 @@ main (int    argc,
     if (job)
         g_object_unref (job);
 
+    if (xfce_screensaver)
+        g_object_unref (xfce_screensaver);
+
     xfconf_shutdown ();
 
     return 0;
